@@ -19,7 +19,7 @@ Usage::
     list_attacks_paginator: ListAttacksPaginator = client.get_paginator("list_attacks")
     list_protections_paginator: ListProtectionsPaginator = client.get_paginator("list_protections")
 """
-from mypy_boto3_shield.client import ShieldClient as Client, ShieldClient
+from mypy_boto3_shield.client import ShieldClient, ShieldClient as Client
 from mypy_boto3_shield.paginator import ListAttacksPaginator, ListProtectionsPaginator
 
 
